function varargout = getmemvar(varargin)
%   function varargout = getmemvar(varargin)
%
%   Purpose:
%   GUI allows user to select variables from the 
%   main MATLAB memory space.
%   ==========================================================================
%   Copyright 2005 Biosystems Data Analysis Group ; Universiteit van Amsterdam
%   ==========================================================================

if ( nargin == 0 | (nargin == 1 & isstruct(varargin{1})) )

  fig = openfig(mfilename,'new');

  % Use system color scheme for figure:
  set(fig,'Color',get(0,'defaultUicontrolBackgroundColor'));

  % Generate a structure of handles to pass to callbacks, and store it. 
  handles           = guihandles(fig);
  if ( nargin == 1 ) 
    %   If a struct argument was passed, it is assumed to be 
    %   the Global Settings struct.
    handles.GlobSet   = varargin{1};
  end    
  
  GlobSet = handles.GlobSet;
  if ( GlobSet.SampleSelection  ) 
      set(handles.RADIOsample,'value',0);
      set(handles.RADIOreference,'value',1);
  else
      set(handles.RADIOsample,'value',1);
      set(handles.RADIOreference,'value',0);
  end
  
  Update_ListWhos(handles);
  guidata(fig, handles);

  if nargout > 0
    varargout{1} = fig;
  end

elseif ischar(varargin{1}) % INVOKE NAMED SUBFUNCTION OR CALLBACK
    try
        if (nargout)
            [varargout{1:nargout}] = feval(varargin{:}); % FEVAL switchyard
        else
            feval(varargin{:}); % FEVAL switchyard
        end
    catch
        disp(lasterr);
    end
end

% --------------------------------------------------------------------        
function Update_ListWhos(handles)
    % Updates the listbox that shows current variables in the main workspace.
    %   Get currenty variables
    vars = evalin('base','whos');
    
    %   Put them in listbox.
    if ( length(vars) > 0 )
        set(handles.ListWhos,'String',char(vars.name));
    else
        set(handles.ListWhos,'String',[]);
    end
    
    GlobSet = handles.GlobSet;
    if ( ~isempty(GlobSet.VarNameSample) )
        set(handles.LBSelectedSample  ,'string',GlobSet.VarNameSample);
    end
    if ( ~isempty(GlobSet.VarNameRef) )
        set(handles.LBSelectedRef     ,'string',GlobSet.VarNameRef);
    end
    
    
% --------------------------------------------------------------------          
function LISTwhos_callback(handles)
    % Return name of the selected base space variable.
    GlobSet         = handles.GlobSet;
    Current_entries = get(handles.ListWhos,'String');
    
    index_selected  = get(handles.ListWhos,'Value');
    nselected       = length(index_selected);
    
    switch( nselected )
    case 1
        if ( GlobSet.SampleSelection )
            GlobSet.VarNameSample   = Current_entries(index_selected(1),:);                    
            set(handles.RADIOsample,'value',0);
            set(handles.RADIOreference,'value',1);
        else
            GlobSet.VarNameRef      = Current_entries(index_selected(1),:);
            set(handles.RADIOsample,'value',1);
            set(handles.RADIOreference,'value',0);
        end 
        GlobSet.SampleSelection = ~GlobSet.SampleSelection;
    otherwise
        errordlg('You must select 1 variable at the time','Incorrect Selection','modal')
    end            
    handles.GlobSet = GlobSet;
    Update_ListWhos(handles);
    guidata(handles.GetMemVar_GUI, handles);

% --------------------------------------------------------------------
function RADIOreference_Callback(handles)
    GlobSet = handles.GlobSet;
    value   = get(handles.RADIOreference,'value');
    if ( value )
        %   User wants to select REFERENCE sample.
        GlobSet.SampleSelection = 0;
        %   Switch of radio button for NEW sample
        set(handles.RADIOsample,'value',0)
    else
        %   User wants to select NEW sample.
        GlobSet.SampleSelection = 1;
        
        set(handles.RADIOsample,'value',1)
    end
    handles.GlobSet = GlobSet;
    guidata(handles.GetMemVar_GUI,handles);

% --------------------------------------------------------------------
function RADIOsample_Callback(handles)
    GlobSet = handles.GlobSet;
    value   = get(handles.RADIOsample,'value');
    'hier'
    if ( value )
        %   User wants to select NEW sample.
        GlobSet.SampleSelection = 1;
        set(handles.RADIOreference,'value',0)
    else
        %   User wants to select REFERENCE sample.
        GlobSet.SampleSelection = 0;
        set(handles.RADIOreference,'value',1)
    end
    handles.GlobSet = GlobSet;
    guidata(handles.GetMemVar_GUI,handles);

% --------------------------------------------------------------------
function BUTok_Callback(handles)
    GlobSet = handles.GlobSet;
    close(handles.GetMemVar_GUI);
    warpgui(GlobSet);