function [strC] = NOTintersectCH(strA,strB)
%   function [strC] = NOTintersectCH(strA,strB)   
%
%   Purpose:
%   Return string in strA that are NOT in strB
%
%   Input:
%   strA    -   First Char array with strings on rows
%   strB    -   Second Char Array 
%
%   Output:
%   strC    -   Char array with strings that are present in
%               strA and strB.
%
%   ==========================================================================
%   Copyright 2005 Biosystems Data Analysis Group ; Universiteit van Amsterdam
%   ==========================================================================
error(nargchk(2,3,nargin));
if ( isempty(strB) )
    strC = strA;
    return
end
if ( ~isstr(strA) | ~isstr(strB) )
    error('NOTintersectCH: input argument must be char arrays')
end

% Make sure that strA and strB contain unique elements.
[strA,ia] = unique(strA,'rows');
[strB,ib] = unique(strB,'rows');
  
% Automatically pad the strings with spaces:
% the strings in 'strA' and 'strB' should have the
% same number of characters to be able to compare them.
if ( size(strA,2) > size(strB,2) ) 
  strB = [strB repmat(' ',size(strB,1),size(strA,2)-size(strB,2))];
end
if ( size(strA,2) < size(strB,2) ) 
  strA = [strA repmat(' ',size(strA,1),size(strB,2)-size(strA,2))];
end
    
% Now, find matching entries
[strC,ndx]      = sortrows([strA;strB]);
[m,n]       = size(strC);
if (m > 1 & n ~= 0)
    % ndxD indicates the location of non-matching entries
    ndxD = strC(1:end-1,:) == strC(2:end,:);
else
    ndxD = zeros(m-1,n);
end
%   Get rows in ndxD having all entries set to 1.
ndxD                = find(all(ndxD,2));

%   Remove those lines in the index.
ndx([ndxD;ndxD+1])  = [];

%   only allow those unique extries that are in strA to be returned. 
ndx                 = ndx(find (ndx <= size(strA,1)));
strC                = deblank(strA(ndx,:));