function [f, sel, g] = interpol(t, y);
% Linear interpolation of signal y for arbitrary t 
% Input
%   t: points at which to compute interpolated values
%   y: signal to be interpolated
% Output
%   f: interpolated signal
%   sel: points of t with 1 <= t & t <= m
%   g: gradient of y at points t
% Implicit assumption: y given on grid 1:m
%
% Paul Eilers, 2002

m = length(y);
sel = find(1 < t & t < m);
ti = floor(t(sel));
tr = t(sel) - ti;
g = y(ti + 1) - y(ti);
f = y(ti) + tr .* g;

