function [w, sel, a] = quadwarp(x, y)
% Parametric warping with quadratic polynomial
% Input
%   x: template signal
%   y: signal to fit
% Output
%   w: warping function
%   sel: part of y that can be fitted; y(sel) 
%   a: coefficients of constant, time and time squared
% Notes
%   1) time implicit: integer series starting at 1, in steps of 1
%   2) plot results as interpol(w, x), i.e. warped x, and y(sel)
%
% Paul Eilers, 2003

% Basis for warping function
m = max(length(x), length(y));
t = (1:m)';
B = [ones(m, 1), t, (t /m) .^ 2];
n = size(B, 2);

% Initialize
a = [0; 1; 0];
rms_old = 0;
for it = 1:40   

   % Interpolate
   w = B * a;
   [z sel g] = interpol(w, x);
    
   % Improve
   r = y(sel) - z;
   rms = sqrt(r' * r / m);
   drms = abs((rms - rms_old) / (rms + 1e-10));
   if drms < 1e-6
      break
   end
   rms_old = rms;
   G = repmat(g, 1, n);
   Q = G .* B(sel, :);
   da = Q \ r;
   a = a + da;
   damax = max(abs(da));
end

a(3) = a(3) / m ^ 2;
